@@ -456,8 +456,8 @@ mutation createSocialConnectionInstance($input: CreateSocialConnectionInstanceIn
 
 """,
 'createUser': """
-mutation createUser($userInfo: CreateUserInput!, $keepPassword: Boolean) {
-  createUser(userInfo: $userInfo, keepPassword: $keepPassword) {
+mutation createUser($userInfo: CreateUserInput!, $params: String, $identity: CreateUserIdentityInput, $keepPassword: Boolean, $resetPasswordOnFirstLogin: Boolean) {
+  createUser(userInfo: $userInfo, params: $params, identity: $identity, keepPassword: $keepPassword, resetPasswordOnFirstLogin: $resetPasswordOnFirstLogin) {
     id
     arn
     userPoolId
@@ -511,6 +511,69 @@ mutation createUser($userInfo: CreateUserInput!, $keepPassword: Boolean) {
   }
 }
 
+""",
+'createUserWithCustomData': """
+mutation createUserWithCustomData($userInfo: CreateUserInput!, $keepPassword: Boolean, $params: String) {
+  createUser(userInfo: $userInfo, keepPassword: $keepPassword, params: $params) {
+    id
+    arn
+    userPoolId
+    status
+    username
+    email
+    emailVerified
+    phone
+    phoneVerified
+    unionid
+    openid
+    nickname
+    registerSource
+    photo
+    password
+    oauth
+    token
+    tokenExpiredAt
+    loginsCount
+    lastLogin
+    lastIP
+    signedUp
+    blocked
+    isDeleted
+    device
+    browser
+    company
+    name
+    givenName
+    familyName
+    middleName
+    profile
+    preferredUsername
+    website
+    gender
+    birthdate
+    zoneinfo
+    locale
+    address
+    formatted
+    streetAddress
+    locality
+    region
+    postalCode
+    city
+    province
+    country
+    createdAt
+    updatedAt
+    externalId
+    customData {
+      key
+      value
+      dataType
+      label
+    }
+  }
+}
+
 """,
 'createUserpool': """
 mutation createUserpool($name: String!, $domain: String!, $description: String, $logo: String, $userpoolTypes: [String!]) {
@@ -1040,6 +1103,15 @@ mutation loginByUsername($input: LoginByUsernameInput!) {
   }
 }
 
+""",
+'moveMembers': """
+mutation moveMembers($userIds: [String!]!, $sourceNodeId: String!, $targetNodeId: String!) {
+  moveMembers(userIds: $userIds, sourceNodeId: $sourceNodeId, targetNodeId: $targetNodeId) {
+    code
+    message
+  }
+}
+
 """,
 'moveNode': """
 mutation moveNode($orgId: String!, $nodeId: String!, $targetParentId: String!) {
@@ -1407,6 +1479,24 @@ mutation resetPassword($phone: String, $email: String, $code: String!, $newPassw
   }
 }
 
+""",
+'resetPasswordByFirstLoginToken': """
+mutation resetPasswordByFirstLoginToken($token: String!, $password: String!) {
+  resetPasswordByFirstLoginToken(token: $token, password: $password) {
+    message
+    code
+  }
+}
+
+""",
+'resetPasswordByForceResetToken': """
+mutation resetPasswordByForceResetToken($token: String!, $oldPassword: String!, $newPassword: String!) {
+  resetPasswordByForceResetToken(token: $token, oldPassword: $oldPassword, newPassword: $newPassword) {
+    message
+    code
+  }
+}
+
 """,
 'revokeRole': """
 mutation revokeRole($namespace: String, $roleCode: String, $roleCodes: [String], $userIds: [String!], $groupCodes: [String!], $nodeCodes: [String!]) {
@@ -1425,6 +1515,15 @@ mutation sendEmail($email: String!, $scene: EmailScene!) {
   }
 }
 
+""",
+'sendFirstLoginVerifyEmail': """
+mutation sendFirstLoginVerifyEmail($userId: String!, $appId: String!) {
+  sendFirstLoginVerifyEmail(userId: $userId, appId: $appId) {
+    message
+    code
+  }
+}
+
 """,
 'setMainDepartment': """
 mutation setMainDepartment($userId: String!, $departmentId: String) {
@@ -1944,6 +2043,12 @@ mutation updateUserpool($input: UpdateUserpoolInput!) {
       limit
       enabled
     }
+    loginFailStrategy
+    loginPasswordFailCheck {
+      timeInterval
+      limit
+      enabled
+    }
     changePhoneStrategy {
       verifyOldPhone
     }
@@ -2088,8 +2193,8 @@ query checkPasswordStrength($password: String!) {
 
 """,
 'childrenNodes': """
-query childrenNodes($orgId: String!, $nodeId: String!) {
-  childrenNodes(orgId: $orgId, nodeId: $nodeId) {
+query childrenNodes($nodeId: String!) {
+  childrenNodes(nodeId: $nodeId) {
     id
     orgId
     name
@@ -2126,7 +2231,64 @@ query emailTemplates {
 
 """,
 'findUser': """
-query findUser($email: String, $phone: String, $username: String, $externalId: String) {
+query findUser($email: String, $phone: String, $username: String, $externalId: String, $identity: FindUserByIdentityInput) {
+  findUser(email: $email, phone: $phone, username: $username, externalId: $externalId, identity: $identity) {
+    id
+    arn
+    userPoolId
+    status
+    username
+    email
+    emailVerified
+    phone
+    phoneVerified
+    unionid
+    openid
+    nickname
+    registerSource
+    photo
+    password
+    oauth
+    token
+    tokenExpiredAt
+    loginsCount
+    lastLogin
+    lastIP
+    signedUp
+    blocked
+    isDeleted
+    device
+    browser
+    company
+    name
+    givenName
+    familyName
+    middleName
+    profile
+    preferredUsername
+    website
+    gender
+    birthdate
+    zoneinfo
+    locale
+    address
+    formatted
+    streetAddress
+    locality
+    region
+    postalCode
+    city
+    province
+    country
+    createdAt
+    updatedAt
+    externalId
+  }
+}
+
+""",
+'findUserWithCustomData': """
+query findUserWithCustomData($email: String, $phone: String, $username: String, $externalId: String) {
   findUser(email: $email, phone: $phone, username: $username, externalId: $externalId) {
     id
     arn
@@ -2178,6 +2340,12 @@ query findUser($email: String, $phone: String, $username: String, $externalId: S
     createdAt
     updatedAt
     externalId
+    customData {
+      key
+      value
+      dataType
+      label
+    }
   }
 }
 
@@ -2264,6 +2432,7 @@ query getUserRoles($id: String!, $namespace: String) {
     roles(namespace: $namespace) {
       totalCount
       list {
+        id
         code
         namespace
         arn
@@ -2356,6 +2525,73 @@ query groupWithUsers($code: String!, $page: Int, $limit: Int) {
   }
 }
 
+""",
+'groupWithUsersWithCustomData': """
+query groupWithUsersWithCustomData($code: String!, $page: Int, $limit: Int) {
+  group(code: $code) {
+    users(page: $page, limit: $limit) {
+      totalCount
+      list {
+        id
+        arn
+        userPoolId
+        username
+        email
+        emailVerified
+        phone
+        phoneVerified
+        unionid
+        openid
+        nickname
+        registerSource
+        photo
+        password
+        oauth
+        token
+        tokenExpiredAt
+        loginsCount
+        lastLogin
+        lastIP
+        signedUp
+        blocked
+        isDeleted
+        device
+        browser
+        company
+        name
+        givenName
+        familyName
+        middleName
+        profile
+        preferredUsername
+        website
+        gender
+        birthdate
+        zoneinfo
+        locale
+        address
+        formatted
+        streetAddress
+        locality
+        region
+        postalCode
+        city
+        province
+        country
+        createdAt
+        updatedAt
+        externalId
+        customData {
+          key
+          value
+          dataType
+          label
+        }
+      }
+    }
+  }
+}
+
 """,
 'groups': """
 query groups($userId: String, $page: Int, $limit: Int, $sortBy: SortByEnum) {
@@ -2894,9 +3130,9 @@ query role($code: String!, $namespace: String) {
 
 """,
 'roleWithUsers': """
-query roleWithUsers($code: String!, $namespace: String) {
+query roleWithUsers($code: String!, $namespace: String, $page: Int, $limit: Int) {
   role(code: $code, namespace: $namespace) {
-    users {
+    users(page: $page, limit: $limit) {
       totalCount
       list {
         id
@@ -2954,6 +3190,74 @@ query roleWithUsers($code: String!, $namespace: String) {
   }
 }
 
+""",
+'roleWithUsersWithCustomData': """
+query roleWithUsersWithCustomData($code: String!, $namespace: String, $page: Int, $limit: Int) {
+  role(code: $code, namespace: $namespace) {
+    users(page: $page, limit: $limit) {
+      totalCount
+      list {
+        id
+        arn
+        status
+        userPoolId
+        username
+        email
+        emailVerified
+        phone
+        phoneVerified
+        unionid
+        openid
+        nickname
+        registerSource
+        photo
+        password
+        oauth
+        token
+        tokenExpiredAt
+        loginsCount
+        lastLogin
+        lastIP
+        signedUp
+        blocked
+        isDeleted
+        device
+        browser
+        company
+        name
+        givenName
+        familyName
+        middleName
+        profile
+        preferredUsername
+        website
+        gender
+        birthdate
+        zoneinfo
+        locale
+        address
+        formatted
+        streetAddress
+        locality
+        region
+        postalCode
+        city
+        province
+        country
+        createdAt
+        updatedAt
+        externalId
+        customData {
+          key
+          value
+          dataType
+          label
+        }
+      }
+    }
+  }
+}
+
 """,
 'roles': """
 query roles($namespace: String, $page: Int, $limit: Int, $sortBy: SortByEnum) {
@@ -3077,6 +3381,72 @@ query searchUser($query: String!, $fields: [String], $page: Int, $limit: Int, $d
   }
 }
 
+""",
+'searchUserWithCustomData': """
+query searchUserWithCustomData($query: String!, $fields: [String], $page: Int, $limit: Int, $departmentOpts: [SearchUserDepartmentOpt], $groupOpts: [SearchUserGroupOpt], $roleOpts: [SearchUserRoleOpt]) {
+  searchUser(query: $query, fields: $fields, page: $page, limit: $limit, departmentOpts: $departmentOpts, groupOpts: $groupOpts, roleOpts: $roleOpts) {
+    totalCount
+    list {
+      id
+      arn
+      userPoolId
+      status
+      username
+      email
+      emailVerified
+      phone
+      phoneVerified
+      unionid
+      openid
+      nickname
+      registerSource
+      photo
+      password
+      oauth
+      token
+      tokenExpiredAt
+      loginsCount
+      lastLogin
+      lastIP
+      signedUp
+      blocked
+      isDeleted
+      device
+      browser
+      company
+      name
+      givenName
+      familyName
+      middleName
+      profile
+      preferredUsername
+      website
+      gender
+      birthdate
+      zoneinfo
+      locale
+      address
+      formatted
+      streetAddress
+      locality
+      region
+      postalCode
+      city
+      province
+      country
+      createdAt
+      updatedAt
+      externalId
+      customData {
+        key
+        value
+        dataType
+        label
+      }
+    }
+  }
+}
+
 """,
 'socialConnection': """
 query socialConnection($provider: String!) {
@@ -3200,6 +3570,7 @@ query user($id: String) {
       connectionId
       isSocial
       provider
+      type
       userPoolId
     }
     unionid
@@ -3248,8 +3619,18 @@ query user($id: String) {
 
 """,
 'userBatch': """
-query userBatch($ids: [String!]!) {
-  userBatch(ids: $ids) {
+query userBatch($ids: [String!]!, $type: String) {
+  userBatch(ids: $ids, type: $type) {
+    identities {
+      openid
+      userIdInIdp
+      userId
+      connectionId
+      isSocial
+      provider
+      type
+      userPoolId
+    }
     id
     arn
     userPoolId
@@ -3303,6 +3684,151 @@ query userBatch($ids: [String!]!) {
   }
 }
 
+""",
+'userBatchWithCustomData': """
+query userBatchWithCustomData($ids: [String!]!, $type: String) {
+  userBatch(ids: $ids, type: $type) {
+    identities {
+      openid
+      userIdInIdp
+      userId
+      connectionId
+      isSocial
+      provider
+      type
+      userPoolId
+    }
+    id
+    arn
+    userPoolId
+    status
+    username
+    email
+    emailVerified
+    phone
+    phoneVerified
+    unionid
+    openid
+    nickname
+    registerSource
+    photo
+    password
+    oauth
+    token
+    tokenExpiredAt
+    loginsCount
+    lastLogin
+    lastIP
+    signedUp
+    blocked
+    isDeleted
+    device
+    browser
+    company
+    name
+    givenName
+    familyName
+    middleName
+    profile
+    preferredUsername
+    website
+    gender
+    birthdate
+    zoneinfo
+    locale
+    address
+    formatted
+    streetAddress
+    locality
+    region
+    postalCode
+    city
+    province
+    country
+    createdAt
+    updatedAt
+    externalId
+    customData {
+      key
+      value
+      dataType
+      label
+    }
+  }
+}
+
+""",
+'userWithCustomData': """
+query userWithCustomData($id: String) {
+  user(id: $id) {
+    id
+    arn
+    userPoolId
+    status
+    username
+    email
+    emailVerified
+    phone
+    phoneVerified
+    identities {
+      openid
+      userIdInIdp
+      userId
+      connectionId
+      isSocial
+      provider
+      userPoolId
+    }
+    unionid
+    openid
+    nickname
+    registerSource
+    photo
+    password
+    oauth
+    token
+    tokenExpiredAt
+    loginsCount
+    lastLogin
+    lastIP
+    signedUp
+    blocked
+    isDeleted
+    device
+    browser
+    company
+    name
+    givenName
+    familyName
+    middleName
+    profile
+    preferredUsername
+    website
+    gender
+    birthdate
+    zoneinfo
+    locale
+    address
+    formatted
+    streetAddress
+    locality
+    region
+    postalCode
+    city
+    province
+    country
+    createdAt
+    updatedAt
+    externalId
+    customData {
+      key
+      value
+      dataType
+      label
+    }
+  }
+}
+
 """,
 'userpool': """
 query userpool {
@@ -3342,6 +3868,12 @@ query userpool {
       limit
       enabled
     }
+    loginPasswordFailCheck {
+      timeInterval
+      limit
+      enabled
+    }
+    loginFailStrategy
     changePhoneStrategy {
       verifyOldPhone
     }
@@ -3421,10 +3953,20 @@ query userpools($page: Int, $limit: Int, $sortBy: SortByEnum) {
 
 """,
 'users': """
-query users($page: Int, $limit: Int, $sortBy: SortByEnum) {
-  users(page: $page, limit: $limit, sortBy: $sortBy) {
+query users($page: Int, $limit: Int, $sortBy: SortByEnum, $excludeUsersInOrg: Boolean) {
+  users(page: $page, limit: $limit, sortBy: $sortBy, excludeUsersInOrg: $excludeUsersInOrg) {
     totalCount
     list {
+      identities {
+        openid
+        userIdInIdp
+        userId
+        connectionId
+        isSocial
+        provider
+        type
+        userPoolId
+      }
       id
       arn
       userPoolId
@@ -3479,6 +4021,82 @@ query users($page: Int, $limit: Int, $sortBy: SortByEnum) {
   }
 }
 
+""",
+'usersWithCustomData': """
+query usersWithCustomData($page: Int, $limit: Int, $sortBy: SortByEnum, $excludeUsersInOrg: Boolean) {
+  users(page: $page, limit: $limit, sortBy: $sortBy, excludeUsersInOrg: $excludeUsersInOrg) {
+    totalCount
+    list {
+      id
+      identities {
+        openid
+        userIdInIdp
+        userId
+        connectionId
+        isSocial
+        provider
+        type
+        userPoolId
+      }
+      arn
+      userPoolId
+      status
+      username
+      email
+      emailVerified
+      phone
+      phoneVerified
+      unionid
+      openid
+      nickname
+      registerSource
+      photo
+      password
+      oauth
+      token
+      tokenExpiredAt
+      loginsCount
+      lastLogin
+      lastIP
+      signedUp
+      blocked
+      isDeleted
+      device
+      browser
+      company
+      name
+      givenName
+      familyName
+      middleName
+      profile
+      preferredUsername
+      website
+      gender
+      birthdate
+      zoneinfo
+      locale
+      address
+      formatted
+      streetAddress
+      locality
+      region
+      postalCode
+      city
+      province
+      country
+      createdAt
+      updatedAt
+      externalId
+      customData {
+        key
+        value
+        dataType
+        label
+      }
+    }
+  }
+}
+
 """,
 'whitelist': """
 query whitelist($type: WhitelistType!) {
